<?php
/**
 * GardenHub theme customizer
 *
 * @package GardenHub
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class GardenHub_Customize {
	/**
	 * Customize settings
	 *
	 * @var array
	 */
	protected $config = array();

	/**
	 * The class constructor
	 *
	 * @param array $config
	 */
	public function __construct( $config ) {
		$this->config = $config;

		if ( ! class_exists( 'Kirki' ) ) {
			return;
		}

		$this->register();
	}

	/**
	 * Register settings
	 */
	public function register() {
		/**
		 * Add the theme configuration
		 */
		if ( ! empty( $this->config['theme'] ) ) {
			Kirki::add_config(
				$this->config['theme'], array(
				'capability'  => 'edit_theme_options',
				'option_type' => 'theme_mod',
			)
			);
		}

		/**
		 * Add panels
		 */
		if ( ! empty( $this->config['panels'] ) ) {
			foreach ( $this->config['panels'] as $panel => $settings ) {
				Kirki::add_panel( $panel, $settings );
			}
		}

		/**
		 * Add sections
		 */
		if ( ! empty( $this->config['sections'] ) ) {
			foreach ( $this->config['sections'] as $section => $settings ) {
				Kirki::add_section( $section, $settings );
			}
		}

		/**
		 * Add fields
		 */
		if ( ! empty( $this->config['theme'] ) && ! empty( $this->config['fields'] ) ) {
			foreach ( $this->config['fields'] as $name => $settings ) {
				if ( ! isset( $settings['settings'] ) ) {
					$settings['settings'] = $name;
				}

				Kirki::add_field( $this->config['theme'], $settings );
			}
		}
	}

	/**
	 * Get config ID
	 *
	 * @return string
	 */
	public function get_theme() {
		return $this->config['theme'];
	}

	/**
	 * Get customize setting value
	 *
	 * @param string $name
	 *
	 * @return bool|string
	 */
	public function get_option( $name ) {

		$default = $this->get_option_default( $name );

		return get_theme_mod( $name, $default );
	}

	/**
	 * Get default option values
	 *
	 * @param $name
	 *
	 * @return mixed
	 */
	public function get_option_default( $name ) {
		if ( ! isset( $this->config['fields'][$name] ) ) {
			return false;
		}

		return isset( $this->config['fields'][$name]['default'] ) ? $this->config['fields'][$name]['default'] : false;
	}
}

/**
 * This is a short hand function for getting setting value from customizer
 *
 * @param string $name
 *
 * @return bool|string
 */
function gardenhub_get_option( $name ) {
	global $gardenhub_customize;

	if ( empty( $gardenhub_customize ) ) {
		return false;
	}

	if ( class_exists( 'Kirki' ) ) {
		$value = Kirki::get_option( $gardenhub_customize->get_theme(), $name );
	} else {
		$value = $gardenhub_customize->get_option( $name );
	}

	return apply_filters( 'gardenhub_get_option', $value, $name );
}

/**
 * Get default option values
 *
 * @param $name
 *
 * @return mixed
 */
function gardenhub_get_option_default( $name ) {
	global $gardenhub_customize;

	if ( empty( $gardenhub_customize ) ) {
		return false;
	}

	return $gardenhub_customize->get_option_default( $name );
}

/**
 * Move some default sections to `general` panel that registered by theme
 *
 * @param object $wp_customize
 */
function gardenhub_customize_modify( $wp_customize ) {
	$wp_customize->get_section( 'title_tagline' )->panel     = 'general';
	$wp_customize->get_section( 'static_front_page' )->panel = 'general';
}

add_action( 'customize_register', 'gardenhub_customize_modify' );


/**
 * Customizer register
 */
$gardenhub_customize = new GardenHub_Customize(
	array(
		'theme'    => 'gardenhub',
		'panels'   => array(
			'general'    => array(
				'priority' => 10,
				'title'    => esc_html__( 'General', 'gardenhub' ),
			),
			'typography' => array(
				'priority' => 10,
				'title'    => esc_html__( 'Typography', 'gardenhub' ),
			),
			'styling'    => array(
				'priority' => 20,
				'title'    => esc_html__( 'Styling', 'gardenhub' ),
			),
			'layout'     => array(
				'title'    => esc_html__( 'Layout', 'gardenhub' ),
				'priority' => 30,
			),
			'header'     => array(
				'priority' => 200,
				'title'    => esc_html__( 'Header', 'gardenhub' ),
			),
			'woocommerce'       => array(
				'priority' => 250,
				'title'    => esc_html__( 'Woocommerce', 'gardenhub' ),
			),
			'content'    => array(
				'title'    => esc_html__( 'Content', 'gardenhub' ),
				'priority' => 300,
			),
			'footer'     => array(
				'title'       => esc_html__( 'Footer', 'gardenhub' ),
				'description' => '',
				'priority'    => 350,
				'capability'  => 'edit_theme_options',
			),
		),
		'sections' => array(
			'body_typo'              => array(
				'title'       => esc_html__( 'Body', 'gardenhub' ),
				'description' => '',
				'priority'    => 210,
				'capability'  => 'edit_theme_options',
				'panel'       => 'typography',
			),
			'heading_typo'           => array(
				'title'       => esc_html__( 'Heading', 'gardenhub' ),
				'description' => '',
				'priority'    => 210,
				'capability'  => 'edit_theme_options',
				'panel'       => 'typography',
			),
			'header_typo'            => array(
				'title'       => esc_html__( 'Header', 'gardenhub' ),
				'description' => '',
				'priority'    => 210,
				'capability'  => 'edit_theme_options',
				'panel'       => 'typography',
			),
			'footer_typo'            => array(
				'title'       => esc_html__( 'Footer', 'gardenhub' ),
				'description' => '',
				'priority'    => 210,
				'capability'  => 'edit_theme_options',
				'panel'       => 'typography',
			),
			'background'             => array(
				'title'       => esc_html__( 'Background', 'gardenhub' ),
				'description' => '',
				'priority'    => 15,
				'capability'  => 'edit_theme_options',
			),
			'topbar'                 => array(
				'title'       => esc_html__( 'Topbar', 'gardenhub' ),
				'description' => '',
				'priority'    => 5,
				'capability'  => 'edit_theme_options',
				'panel'       => 'header',
			),
			'site_layout'            => array(
				'title'       => esc_html__( 'Site Layout', 'gardenhub' ),
				'description' => '',
				'priority'    => 10,
				'capability'  => 'edit_theme_options',
				'panel'       => 'layout',
			),
			'color_scheme'           => array(
				'title'       => esc_html__( 'Color Scheme', 'gardenhub' ),
				'description' => '',
				'priority'    => 210,
				'capability'  => 'edit_theme_options',
				'panel'       => 'styling',
			),
			'header'                 => array(
				'title'       => esc_html__( 'Header', 'gardenhub' ),
				'description' => '',
				'priority'    => 10,
				'capability'  => 'edit_theme_options',
				'panel'       => 'header',
			),
			'logo'                   => array(
				'title'       => esc_html__( 'Logo', 'gardenhub' ),
				'description' => '',
				'priority'    => 15,
				'capability'  => 'edit_theme_options',
				'panel'       => 'header',
			),
			'page_header'            => array(
				'title'       => esc_html__( 'Page Header', 'gardenhub' ),
				'description' => '',
				'priority'    => 20,
				'capability'  => 'edit_theme_options',
				'panel'       => 'header',
			),
			'woocommerce_product_catalog' => array(
				'title'       => esc_html__( 'Product Catalog', 'gardenhub' ),
				'description' => '',
				'priority'    => 10,
				'panel'       => 'woocommerce',
				'capability'  => 'edit_theme_options',
			),
			'excerpt_length_section' => array(
				'title'       => esc_html__( 'Excerpt Length', 'gardenhub' ),
				'description' => '',
				'priority'    => 5,
				'capability'  => 'edit_theme_options',
				'panel'       => 'content',
			),
			'blog'                   => array(
				'title'       => esc_html__( 'Blog', 'gardenhub' ),
				'description' => '',
				'priority'    => 10,
				'capability'  => 'edit_theme_options',
				'panel'       => 'content',
			),
			'single_post'            => array(
				'title'       => esc_html__( 'Single Post', 'gardenhub' ),
				'description' => '',
				'priority'    => 10,
				'capability'  => 'edit_theme_options',
				'panel'       => 'content',
			),
			'projects'               => array(
				'title'       => esc_html__( 'Projects', 'gardenhub' ),
				'description' => '',
				'priority'    => 20,
				'capability'  => 'edit_theme_options',
				'panel'       => 'content',
			),
			'single_project'         => array(
				'title'       => esc_html__( 'Single Project', 'gardenhub' ),
				'description' => '',
				'priority'    => 20,
				'capability'  => 'edit_theme_options',
				'panel'       => 'content',
			),
			'services'               => array(
				'title'       => esc_html__( 'Services', 'gardenhub' ),
				'description' => '',
				'priority'    => 30,
				'capability'  => 'edit_theme_options',
				'panel'       => 'content',
			),
			'footer_setting'         => array(
				'title'       => esc_html__( 'Footer Setting', 'gardenhub' ),
				'description' => '',
				'priority'    => 350,
				'capability'  => 'edit_theme_options',
				'panel'       => 'footer',
			),
			'footer_layout'          => array(
				'title'       => esc_html__( 'Footer Layout', 'gardenhub' ),
				'description' => '',
				'priority'    => 350,
				'capability'  => 'edit_theme_options',
				'panel'       => 'footer',
			),
		),
		'fields'   => array(
			// Typography
			'body_typo'              => array(
				'type'     => 'typography',
				'label'    => esc_html__( 'Body', 'gardenhub' ),
				'section'  => 'body_typo',
				'priority' => 10,
				'default'  => array(
					'font-family'    => 'Roboto',
					'variant'        => '300',
					'font-size'      => '16px',
					'line-height'    => '1.6',
					'letter-spacing' => '0',
					'subsets'        => array( 'latin-ext' ),
					'color'          => '#848484',
					'text-transform' => 'none',
				),
			),
			'heading1_typo'          => array(
				'type'     => 'typography',
				'label'    => esc_html__( 'Heading 1', 'gardenhub' ),
				'section'  => 'heading_typo',
				'priority' => 10,
				'default'  => array(
					'font-family'    => 'Poppins',
					'variant'        => '600',
					'font-size'      => '36px',
					'line-height'    => '1.2',
					'letter-spacing' => '0',
					'subsets'        => array( 'latin-ext' ),
					'color'          => '#222222',
					'text-transform' => 'none',
				),
			),
			'heading2_typo'          => array(
				'type'     => 'typography',
				'label'    => esc_html__( 'Heading 2', 'gardenhub' ),
				'section'  => 'heading_typo',
				'priority' => 10,
				'default'  => array(
					'font-family'    => 'Poppins',
					'variant'        => '600',
					'font-size'      => '30px',
					'line-height'    => '1.2',
					'letter-spacing' => '0',
					'subsets'        => array( 'latin-ext' ),
					'color'          => '#222222',
					'text-transform' => 'none',
				),
			),
			'heading3_typo'          => array(
				'type'     => 'typography',
				'label'    => esc_html__( 'Heading 3', 'gardenhub' ),
				'section'  => 'heading_typo',
				'priority' => 10,
				'default'  => array(
					'font-family'    => 'Poppins',
					'variant'        => '600',
					'font-size'      => '24px',
					'line-height'    => '1.2',
					'letter-spacing' => '0',
					'subsets'        => array( 'latin-ext' ),
					'color'          => '#222222',
					'text-transform' => 'none',
				),
			),
			'heading4_typo'          => array(
				'type'     => 'typography',
				'label'    => esc_html__( 'Heading 4', 'gardenhub' ),
				'section'  => 'heading_typo',
				'priority' => 10,
				'default'  => array(
					'font-family'    => 'Poppins',
					'variant'        => '600',
					'font-size'      => '18px',
					'line-height'    => '1.2',
					'letter-spacing' => '0',
					'subsets'        => array( 'latin-ext' ),
					'color'          => '#222222',
					'text-transform' => 'none',
				),
			),
			'heading5_typo'          => array(
				'type'     => 'typography',
				'label'    => esc_html__( 'Heading 5', 'gardenhub' ),
				'section'  => 'heading_typo',
				'priority' => 10,
				'default'  => array(
					'font-family'    => 'Poppins',
					'variant'        => '600',
					'font-size'      => '16px',
					'line-height'    => '1.2',
					'letter-spacing' => '0',
					'subsets'        => array( 'latin-ext' ),
					'color'          => '#222222',
					'text-transform' => 'none',
				),
			),
			'heading6_typo'          => array(
				'type'     => 'typography',
				'label'    => esc_html__( 'Heading 6', 'gardenhub' ),
				'section'  => 'heading_typo',
				'priority' => 10,
				'default'  => array(
					'font-family'    => 'Poppins',
					'variant'        => '600',
					'font-size'      => '12px',
					'line-height'    => '1.2',
					'letter-spacing' => '0',
					'subsets'        => array( 'latin-ext' ),
					'color'          => '#222222',
					'text-transform' => 'none',
				),
			),
			'menu_typo'              => array(
				'type'     => 'typography',
				'label'    => esc_html__( 'Menu', 'gardenhub' ),
				'section'  => 'header_typo',
				'priority' => 10,
				'default'  => array(
					'font-family'    => 'Poppins',
					'variant'        => '600',
					'subsets'        => array( 'latin-ext' ),
					'font-size'      => '14px',
					'color'          => '#fff',
					'text-transform' => 'none',
				),
			),
			'footer_text_typo'       => array(
				'type'     => 'typography',
				'label'    => esc_html__( 'Footer Text', 'gardenhub' ),
				'section'  => 'footer_typo',
				'priority' => 10,
				'default'  => array(
					'font-family' => 'Roboto',
					'variant'     => '300',
					'subsets'     => array( 'latin-ext' ),
					'font-size'   => '16px',
				),
			),
			// Background
			'404_bg'                 => array(
				'type'        => 'image',
				'label'       => esc_html__( '404 Page', 'gardenhub' ),
				'description' => esc_html__( 'Background image for not found page', 'gardenhub' ),
				'section'     => 'background',
				'default'     => '',
				'priority'    => 10,
			),

			// Layout
			'layout_default'         => array(
				'type'        => 'radio-image',
				'label'       => esc_html__( 'Default Layout', 'gardenhub' ),
				'description' => esc_html__( 'Default layout for blog and posts', 'gardenhub' ),
				'section'     => 'site_layout',
				'default'     => 'no-sidebar',
				'priority'    => 10,
				'choices'     => array(
					'no-sidebar'   => get_template_directory_uri() . '/img/sidebars/empty.png',
					'single-left'  => get_template_directory_uri() . '/img/sidebars/single-left.png',
					'single-right' => get_template_directory_uri() . '/img/sidebars/single-right.png',
				),
			),

			'layout_page'            => array(
				'type'        => 'radio-image',
				'label'       => esc_html__( 'Page Layout', 'gardenhub' ),
				'description' => esc_html__( 'Default layout pages', 'gardenhub' ),
				'section'     => 'site_layout',
				'default'     => 'no-sidebar',
				'priority'    => 10,
				'choices'     => array(
					'no-sidebar'   => get_template_directory_uri() . '/img/sidebars/empty.png',
					'single-left'  => get_template_directory_uri() . '/img/sidebars/single-left.png',
					'single-right' => get_template_directory_uri() . '/img/sidebars/single-right.png',
				),
			),

			'layout_shop'            => array(
				'type'        => 'radio-image',
				'label'       => esc_html__( 'Shop Layout', 'gardenhub' ),
				'description' => esc_html__( 'Default layout shop pages', 'gardenhub' ),
				'section'     => 'site_layout',
				'default'     => 'no-sidebar',
				'priority'    => 10,
				'choices'     => array(
					'no-sidebar'   => get_template_directory_uri() . '/img/sidebars/empty.png',
					'single-left'  => get_template_directory_uri() . '/img/sidebars/single-left.png',
					'single-right' => get_template_directory_uri() . '/img/sidebars/single-right.png',
				),
			),

			'layout_service'         => array(
				'type'        => 'radio-image',
				'label'       => esc_html__( 'Service Layout', 'gardenhub' ),
				'description' => esc_html__( 'Default layout service archive and service categories', 'gardenhub' ),
				'section'     => 'site_layout',
				'default'     => 'no-sidebar',
				'priority'    => 10,
				'choices'     => array(
					'no-sidebar'   => get_template_directory_uri() . '/img/sidebars/empty.png',
					'single-left'  => get_template_directory_uri() . '/img/sidebars/single-left.png',
					'single-right' => get_template_directory_uri() . '/img/sidebars/single-right.png',
				),
			),

			'layout_single_service'  => array(
				'type'        => 'radio-image',
				'label'       => esc_html__( 'Single Service Layout', 'gardenhub' ),
				'description' => esc_html__( 'Default layout single service', 'gardenhub' ),
				'section'     => 'site_layout',
				'default'     => 'single-left',
				'priority'    => 10,
				'choices'     => array(
					'no-sidebar'   => get_template_directory_uri() . '/img/sidebars/empty.png',
					'single-left'  => get_template_directory_uri() . '/img/sidebars/single-left.png',
					'single-right' => get_template_directory_uri() . '/img/sidebars/single-right.png',
				),
			),

			'layout_project'         => array(
				'type'        => 'radio-image',
				'label'       => esc_html__( 'Project Layout', 'gardenhub' ),
				'description' => esc_html__( 'Default layout project archive and project categories', 'gardenhub' ),
				'section'     => 'site_layout',
				'default'     => 'no-sidebar',
				'priority'    => 10,
				'choices'     => array(
					'no-sidebar'   => get_template_directory_uri() . '/img/sidebars/empty.png',
					'single-left'  => get_template_directory_uri() . '/img/sidebars/single-left.png',
					'single-right' => get_template_directory_uri() . '/img/sidebars/single-right.png',
				),
			),
			// Topbar
			'topbar_enable'          => array(
				'type'     => 'toggle',
				'label'    => esc_html__( 'Show topbar', 'gardenhub' ),
				'section'  => 'topbar',
				'default'  => 1,
				'priority' => 10,
			),
			'topbar_style'           => array(
				'type'     => 'select',
				'label'    => esc_html__( 'Topbar Style', 'gardenhub' ),
				'default'  => '1',
				'section'  => 'topbar',
				'priority' => 30,
				'choices'  => array(
					'1' => esc_html__( 'Style 1 ( Dark )', 'gardenhub' ),
					'2' => esc_html__( 'Style 2 ( Light )', 'gardenhub' ),
				),
			),
			'topbar_mobile'          => array(
				'type'     => 'toggle',
				'label'    => esc_html__( 'Hide topbar on mobile', 'gardenhub' ),
				'section'  => 'topbar',
				'default'  => 1,
				'priority' => 15,
			),
			'topbar_bg_color'        => array(
				'type'        => 'color',
				'label'       => esc_html__( 'Topbar Background Color', 'gardenhub' ),
				'description' => esc_html__( 'Background Color for topbar area', 'gardenhub' ),
				'section'     => 'topbar',
				'default'     => '#1d1d1d',
				'priority'    => 20,
			),

			// Color Scheme
			'color_scheme'           => array(
				'type'     => 'radio-image',
				'label'    => esc_html__( 'Base Color Scheme', 'gardenhub' ),
				'default'  => '0',
				'section'  => 'color_scheme',
				'priority' => 10,
				'choices'  => array(
					'0'       => get_template_directory_uri() . '/img/color/color-8.png',
					'#2f43a9' => get_template_directory_uri() . '/img/color/color-3.png',
					'#2991d6' => get_template_directory_uri() . '/img/color/color-4.png',
					'#6c98e1' => get_template_directory_uri() . '/img/color/color-5.png',
					'#ff5a00' => get_template_directory_uri() . '/img/color/color-6.png',
					'#f71414' => get_template_directory_uri() . '/img/color/color-7.png',
					'#fac012' => get_template_directory_uri() . '/img/color/color-1.png',
				),
			),
			'custom_color_scheme'    => array(
				'type'     => 'toggle',
				'label'    => esc_html__( 'Custom Color Scheme', 'gardenhub' ),
				'default'  => 0,
				'section'  => 'color_scheme',
				'priority' => 10,
			),
			'custom_color'           => array(
				'type'            => 'color',
				'label'           => esc_html__( 'Color', 'gardenhub' ),
				'default'         => '',
				'section'         => 'color_scheme',
				'priority'        => 10,
				'active_callback' => array(
					array(
						'setting'  => 'custom_color_scheme',
						'operator' => '==',
						'value'    => 1,
					),
				),
			),

			// Header layout
			'header_layout'          => array(
				'type'     => 'select',
				'label'    => esc_html__( 'Header Layout', 'gardenhub' ),
				'section'  => 'header',
				'default'  => 'v1',
				'priority' => 10,
				'choices'  => array(
					'v1' => esc_html__( 'Header v1', 'gardenhub' ),
					'v2' => esc_html__( 'Header v2', 'gardenhub' ),
					'v3' => esc_html__( 'Header v3', 'gardenhub' ),
					'v4' => esc_html__( 'Header v4', 'gardenhub' ),
				),
			),

			'header_sticky'          => array(
				'type'     => 'toggle',
				'label'    => esc_html__( 'Sticky Header', 'gardenhub' ),
				'default'  => 0,
				'section'  => 'header',
				'priority' => 40,
			),

			'header_extra_text'      => array(
				'type'     => 'textarea',
				'label'    => esc_html__( 'Header Extra Text', 'gardenhub' ),
				'section'  => 'header',
				'default'  => '',
				'priority' => 15,
			),

			'extra_text'             => array(
				'type'            => 'textarea',
				'label'           => esc_html__( 'Menu Extra Text', 'gardenhub' ),
				'section'         => 'header',
				'default'         => '',
				'priority'        => 35,
				'active_callback' => array(
					array(
						'setting'  => 'header_layout',
						'operator' => 'in',
						'value'    => array( 'v1', 'v3' ),
					),
				),
			),

			'hover_effect'           => array(
				'type'     => 'toggle',
				'label'    => esc_html__( 'Enable/Disable Effect when hover on menu item', 'gardenhub' ),
				'default'  => 1,
				'section'  => 'header',
				'priority' => 40,
			),

			'header_search'          => array(
				'type'            => 'toggle',
				'label'           => esc_html__( 'Enable Search Item', 'gardenhub' ),
				'section'         => 'header',
				'default'         => 1,
				'priority'        => 55,
				'active_callback' => array(
					array(
						'setting'  => 'header_layout',
						'operator' => 'in',
						'value'    => array( 'v2', 'v4' ),
					),
				),
			),

			// Logo
			'logo_dark'              => array(
				'type'     => 'image',
				'label'    => esc_html__( 'Logo', 'gardenhub' ),
				'section'  => 'logo',
				'default'  => '',
				'priority' => 10,
			),
			'logo_light'             => array(
				'type'     => 'image',
				'label'    => esc_html__( 'Logo Light', 'gardenhub' ),
				'section'  => 'logo',
				'default'  => '',
				'priority' => 10,
			),
			'logo_width'             => array(
				'type'     => 'number',
				'label'    => esc_html__( 'Logo Width', 'gardenhub' ),
				'section'  => 'logo',
				'default'  => '',
				'priority' => 10,
			),
			'logo_height'            => array(
				'type'     => 'number',
				'label'    => esc_html__( 'Logo Height', 'gardenhub' ),
				'section'  => 'logo',
				'default'  => '',
				'priority' => 10,
			),
			'logo_position'          => array(
				'type'     => 'spacing',
				'label'    => esc_html__( 'Logo Margin', 'gardenhub' ),
				'section'  => 'logo',
				'priority' => 10,
				'default'  => array(
					'top'    => '0',
					'bottom' => '0',
					'left'   => '0',
					'right'  => '0',
				),
			),
			// Page header
			'page_header_enable'     => array(
				'type'     => 'toggle',
				'label'    => esc_html__( 'Show Page Header', 'gardenhub' ),
				'section'  => 'page_header',
				'default'  => 1,
				'priority' => 10,
			),
			'page_header_bg'         => array(
				'type'        => 'image',
				'label'       => esc_html__( 'Page Header Image', 'gardenhub' ),
				'description' => esc_html__( 'The default background image for page header', 'gardenhub' ),
				'section'     => 'page_header',
				'default'     => '',
				'priority'    => 10,
			),
			'shop_page_header_bg'    => array(
				'type'        => 'image',
				'label'       => esc_html__( 'Shop Page Header Image', 'gardenhub' ),
				'description' => esc_html__( 'The default background image for page header on shop page', 'gardenhub' ),
				'section'     => 'page_header',
				'default'     => '',
				'priority'    => 10,
			),
			'show_breadcrumb'        => array(
				'type'     => 'toggle',
				'label'    => esc_html__( 'Show Breadcrumb', 'gardenhub' ),
				'section'  => 'page_header',
				'default'  => 1,
				'priority' => 10,
			),
			// Header script
			'related_product_columns'        => array(
				'type'     => 'select',
				'label'    => esc_html__( 'Related Product Columns', 'gardenhub' ),
				'section'  => 'woocommerce_product_catalog',
				'default'  => '3',
				'priority' => 90,
				'choices'  => array(
					'3' => esc_html__( '3', 'gardenhub' ),
					'4' => esc_html__( '4', 'gardenhub' ),
				),
			),

			// Content
			'excerpt_length'         => array(
				'type'     => 'number',
				'label'    => esc_html__( 'Excerpt Length', 'gardenhub' ),
				'section'  => 'excerpt_length_section',
				'default'  => 20,
				'priority' => 10,
			),
			'blog_layout'            => array(
				'type'     => 'radio',
				'label'    => esc_html__( 'Blog Layout', 'gardenhub' ),
				'section'  => 'blog',
				'default'  => 'classic',
				'priority' => 10,
				'choices'  => array(
					'classic' => esc_html__( 'Classic', 'gardenhub' ),
					'grid'    => esc_html__( 'Grid', 'gardenhub' ),
				),
			),
			'blog_grid_columns'      => array(
				'type'            => 'select',
				'label'           => esc_html__( 'Blog Grid Columns', 'gardenhub' ),
				'section'         => 'blog',
				'default'         => '2',
				'priority'        => 10,
				'choices'         => array(
					'2' => esc_html__( '2 Columns', 'gardenhub' ),
					'3' => esc_html__( '3 Columns', 'gardenhub' ),
				),
				'active_callback' => array(
					array(
						'setting'  => 'blog_layout',
						'operator' => '==',
						'value'    => 'grid',
					),
				),
			),
			'blog_entry_meta'        => array(
				'type'     => 'multicheck',
				'label'    => esc_html__( 'Entry Meta', 'gardenhub' ),
				'section'  => 'blog',
				'default'  => array( 'date', 'view', 'comment' ),
				'choices'  => array(
					'author'  => esc_html__( 'Author', 'gardenhub' ),
					'date'    => esc_html__( 'Date', 'gardenhub' ),
					'tag'     => esc_html__( 'Tags', 'gardenhub' ),
					'comment' => esc_html__( 'Comment', 'gardenhub' ),
					'view'    => esc_html__( 'View', 'gardenhub' ),
				),
				'priority' => 10,
			),

			// Single Post

			'post_entry_meta'        => array(
				'type'     => 'multicheck',
				'label'    => esc_html__( 'Entry Meta', 'gardenhub' ),
				'section'  => 'single_post',
				'default'  => array( 'author', 'view', 'comment' ),
				'choices'  => array(
					'author'  => esc_html__( 'Author', 'gardenhub' ),
					'date'    => esc_html__( 'Date', 'gardenhub' ),
					'tag'     => esc_html__( 'Tags', 'gardenhub' ),
					'comment' => esc_html__( 'Comment', 'gardenhub' ),
					'view'    => esc_html__( 'View', 'gardenhub' ),
				),
				'priority' => 10,
			),
			'show_post_social_share' => array(
				'type'        => 'toggle',
				'label'       => esc_html__( 'Show Socials Share', 'gardenhub' ),
				'description' => esc_html__( 'Check this option to show socials share in the single post page.', 'gardenhub' ),
				'section'     => 'single_post',
				'default'     => 1,
				'priority'    => 10,
			),

			'post_socials_share'     => array(
				'type'            => 'multicheck',
				'label'           => esc_html__( 'Socials Share', 'gardenhub' ),
				'section'         => 'single_post',
				'default'         => array( 'facebook', 'twitter', 'google', 'linkedin' ),
				'choices'         => array(
					'twitter'   => esc_html__( 'Twitter', 'gardenhub' ),
					'facebook'  => esc_html__( 'Facebook', 'gardenhub' ),
					'google'    => esc_html__( 'Google Plus', 'gardenhub' ),
					'pinterest' => esc_html__( 'Pinterest', 'gardenhub' ),
					'linkedin'  => esc_html__( 'Linkedin', 'gardenhub' ),
					'vkontakte' => esc_html__( 'Vkontakte', 'gardenhub' ),
				),
				'priority'        => 10,
				'active_callback' => array(
					array(
						'setting'  => 'show_post_social_share',
						'operator' => '==',
						'value'    => 1,
					),
				),
			),
			'show_author_box'        => array(
				'type'     => 'toggle',
				'label'    => esc_html__( 'Show Author Box', 'gardenhub' ),
				'section'  => 'single_post',
				'default'  => 0,
				'priority' => 30,
			),

			// Project

			'project_per_page'       => array(
				'type'     => 'number',
				'label'    => esc_html__( 'Project Per Page', 'gardenhub' ),
				'section'  => 'projects',
				'default'  => 10,
				'priority' => 10,
			),
			'project_columns'        => array(
				'type'     => 'select',
				'label'    => esc_html__( 'Project Columns', 'gardenhub' ),
				'section'  => 'projects',
				'default'  => '2',
				'priority' => 30,
				'choices'  => array(
					'2' => esc_html__( '2 Columns', 'gardenhub' ),
					'3' => esc_html__( '3 Columns', 'gardenhub' ),
					'4' => esc_html__( '4 Columns', 'gardenhub' ),
				),
			),
			'project_filter'         => array(
				'type'     => 'toggle',
				'label'    => esc_html__( 'Show Nav Filter', 'gardenhub' ),
				'section'  => 'projects',
				'default'  => 1,
				'priority' => 30,
			),
			'project_nav_type'       => array(
				'type'     => 'radio',
				'label'    => esc_html__( 'Navigation Type', 'gardenhub' ),
				'section'  => 'projects',
				'priority' => 30,
				'default'  => 'ajax',
				'choices'  => array(
					'link' => esc_html__( 'Numeric', 'gardenhub' ),
					'ajax' => esc_html__( 'Ajax', 'gardenhub' ),
				),
			),

			// Services

			'service_per_page'       => array(
				'type'     => 'number',
				'label'    => esc_html__( 'Service Per Page', 'gardenhub' ),
				'section'  => 'services',
				'default'  => 6,
				'priority' => 60,
			),
			'service_button_text'    => array(
				'type'     => 'text',
				'label'    => esc_html__( 'Service Button Text', 'gardenhub' ),
				'section'  => 'services',
				'default'  => esc_html__( 'Read More', 'gardenhub' ),
				'priority' => 60,
			),
			// Footer
			'back_to_top'            => array(
				'type'     => 'toggle',
				'label'    => esc_html__( 'Back to Top', 'gardenhub' ),
				'section'  => 'footer_setting',
				'default'  => 1,
				'priority' => 10,
			),
			'footer_widget'          => array(
				'type'     => 'toggle',
				'label'    => esc_html__( 'Foot Widgets', 'gardenhub' ),
				'section'  => 'footer_setting',
				'default'  => 1,
				'priority' => 10,
			),
			'footer_copyright'       => array(
				'type'     => 'textarea',
				'label'    => esc_html__( 'Footer Copyright', 'gardenhub' ),
				'section'  => 'footer_setting',
				'default'  => esc_html__( 'Copyright @ 2017', 'gardenhub' ),
				'priority' => 10,
			),
			'footer_socials'         => array(
				'type'     => 'repeater',
				'label'    => esc_html__( 'Socials', 'gardenhub' ),
				'section'  => 'footer_setting',
				'priority' => 20,
				'default'  => array(
					array(
						'link_url' => 'https://facebook.com/',
					),
					array(
						'link_url' => 'https://twitter.com/',
					),
					array(
						'link_url' => 'https://www.skype.com/',
					),
					array(
						'link_url' => 'https://www.instagram.com/',
					),
				),
				'fields'   => array(
					'link_url' => array(
						'type'        => 'text',
						'label'       => esc_html__( 'Social URL', 'gardenhub' ),
						'description' => esc_html__( 'Enter the URL for this social', 'gardenhub' ),
						'default'     => '',
					),
				),
			),
			'footer_widget_columns'  => array(
				'type'        => 'radio-image',
				'label'       => esc_html__( 'Footer Widget Columns', 'gardenhub' ),
				'description' => esc_html__( 'How many sidebar you want to show on footer', 'gardenhub' ),
				'section'     => 'footer_setting',
				'default'     => '4',
				'priority'    => 10,
				'choices'     => array(
					'1' => get_template_directory_uri() . '/img/footer/one-column.png',
					'2' => get_template_directory_uri() . '/img/footer/two-columns.png',
					'3' => get_template_directory_uri() . '/img/footer/three-columns.png',
					'4' => get_template_directory_uri() . '/img/footer/four-columns.png',
				),
			),
			'footer_widget_bg'       => array(
				'type'        => 'image',
				'label'       => esc_html__( 'Footer Widget Background', 'gardenhub' ),
				'description' => esc_html__( 'Background image for footer widget area', 'gardenhub' ),
				'section'     => 'footer_layout',
				'default'     => '',
				'priority'    => 15,
			),
			'footer_widget_bg_color' => array(
				'type'        => 'color',
				'label'       => esc_html__( 'Footer Widget Background Color', 'gardenhub' ),
				'description' => esc_html__( 'Background Color for footer widget area', 'gardenhub' ),
				'section'     => 'footer_layout',
				'default'     => '#161616',
				'priority'    => 20,
			),
			'footer_bg_color'        => array(
				'type'        => 'color',
				'label'       => esc_html__( 'Footer Background Color', 'gardenhub' ),
				'description' => esc_html__( 'Background Color for footer area', 'gardenhub' ),
				'section'     => 'footer_layout',
				'default'     => '#1d1d1d',
				'priority'    => 25,
			),
		),
	)
);
